@@ -33,9 +33,10 @@
 #  define KNEWSTUFF_DEPRECATED_NO_EXPORT KNEWSTUFF_NO_EXPORT KNEWSTUFF_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KNEWSTUFF_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KNEWSTUFF_NO_DEPRECATED
+#    define KNEWSTUFF_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
